@@ -39,7 +39,7 @@ function(vari1,vari2,infile1,infile2,outfile){
    v_missing_value = "undefined"
 
    info = "Created with the CM SAF R toolbox."
-   var_prec="double"
+   var_prec="float"
 
    att_list <- c("standard_name","units","_FillValue","missing_value","calendar")
    v_att_list <- c("v_standard_name","v_units","v__FillValue","v_missing_value","v_calendar")
